##  Creating Multiple Transformations in Bulk
Instead of creating each transformation individually, you can create numerous transformations in one go by switching to table view mode. It is particularly useful when dealing with a large number of changes, which can be tedious and time-consuming, for example, for initiatives like ERP transformation.
To create multiple transformations in one go, do the following:
  1. Open the initiative fact sheet in which the transformations are to be created.
  2. Go to the Transformations tab and switch to table view mode by selecting the table icon.
![Selecting Table View Mode](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2752c8667a441014af4ac451e06829bb_LowRes.png)
Selecting Table View Mod
  3. By default, transformations of only one type are listed in the table. From the drop-down menu above the table, select the type of transformations to be listed.
  4. At the bottom left corner of the table, hover over the '+' icon and click Create Transformations.
  5. Depending on the transformation type, relevant fact sheet types are listed. Select the required fact sheet type from the list.
  6. From the overly that opens, select all the fact sheets and click Use Selected Fact Sheets.
  7. Complete the information in other columns as needed.
     * You can copy and paste information from cells and also autofill columns by pulling down the drag handle at the bottom right corner of a cell.
     * While editing completion dates, you can choose between dates or milestones.
  8. Click Save at the end to complete.


![Creating Multiple Transformations in Bulk](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274651427a4410149528e50fde31da0d_LowRes.gif)
Creating Multiple Transformations at Once
Alternatively, you can right-click on any column containing fact sheets and select Create Transformations. Ensure you are in edit mode before doing this by clicking Edit first in the upper-right corner of the table.
